@@ -10,8 +10,7 @@ from jiraConnect import JiraConnect, JiraConnectConnectionError, JiraConnectActi
 
 class TaskExtractor:
 
-    def __init__(self, jira_url, username, password, options, dry_run = False):
-        self.h5_tasks_to_link_to_h4_task = [] # will be used to link h5-tasks to the root task
+    def __init__(self, jira_url, username, password, options = {}, dry_run = False):
         self.tmpl_vars = {} # template variables dict
         self.tmpl_json = {} # template json structures, for example {"project": {"key": "KEY"}}
         self.rt_vars = {} # run-time variables (issueIDs)
@@ -205,7 +204,8 @@ class TaskExtractor:
                         h5_summary_list = self._h5_task_completion(h5_task_key, h5_task_caption, h5_task_desc, h5_task_ext)
                         summary = '\n'.join([summary, h5_summary_list]) if summary else h5_summary_list
                         h5_task_ext = ''
-                    h5_task_key, h5_task_caption, h5_task_desc = self._create_h5_task_and_return_key_caption_description(line)
+                    h4_link = h4_task_key if 'h4_task_key' in vars() else None
+                    h5_task_key, h5_task_caption, h5_task_desc = self._create_h5_task_and_return_key_caption_description(line, h4_link)
                 elif line['markup'][0] == '#':
                     if 'h5_task_key' in vars():
                         sub_task_caption = self._create_sub_task_and_return_caption(line, h5_task_key)
@@ -250,10 +250,10 @@ class TaskExtractor:
         sub_task_key = self.create_issue(sub_task_json)
         return self._make_task_caption(sub_task_json,  sub_task_key)
 
-    def _create_h5_task_and_return_key_caption_description(self, h5_task_json):
+    def _create_h5_task_and_return_key_caption_description(self, h5_task_json, h4_link):
         h5_task_json['issuetype'] = 'Task'
         h5_task_key = self.create_issue(h5_task_json)
-        self.h5_tasks_to_link_to_h4_task.append(h5_task_key)
+        if h4_link is not None: self.create_link(h4_link, h5_task_key)
         h5_task_caption = self._make_task_caption(h5_task_json,  h5_task_key)
         h5_task_desc = h5_task_json['description'] if 'description' in h5_task_json else None
         return (h5_task_key, h5_task_caption, h5_task_desc)
@@ -261,8 +261,6 @@ class TaskExtractor:
     def _create_h4_task_and_return_key_caption(self, h4_task_json):
         h4_task_json['issuetype'] = 'User Story'
         h4_task_key = self.create_issue(h4_task_json)
-        for key in self.h5_tasks_to_link_to_h4_task:
-            self.create_link(h4_task_key, key)
         return (h4_task_key, self._make_task_caption(h4_task_json,  h4_task_key))
 
 # end of create_tasks() helpers
